==> haskell-tasty-checklist-1.0.6.0-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-checklist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-checklist
version:              1.0.6.0
visibility:           public
id:                   tasty-checklist-1.0.6.0-BVE852oNI7S7m8FvFGHeBi
key:                  tasty-checklist-1.0.6.0-BVE852oNI7S7m8FvFGHeBi
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Check multiple items during a tasty test
description:
    Allows the test to check a number of items during a test and
    only signal pass or fail when the end if the checklist is reached.

    Also provides an easy method to check multiple derived values from
    a single input value.

category:             Testing
abi:                  ca0f828075cacf8fce7cb108e2e7ebc6
exposed:              True
exposed-modules:      Test.Tasty.Checklist
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-checklist
hs-libraries:         HStasty-checklist-1.0.6.0-BVE852oNI7S7m8FvFGHeBi
depends:
    base-4.17.2.1 containers-0.6.7 exceptions-0.10.5
    parameterized-utils-2.1.10.0-LsM2EVWNFum7yzpbjXTvaE text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-checklist/html/tasty-checklist.haddock

haddock-html:         /usr/share/doc/haskell-tasty-checklist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-checklist-1.0.6.0-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-checklist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-checklist
version:              1.0.6.0
visibility:           public
id:                   tasty-checklist-1.0.6.0-A2pUb4I7ATf5kS2zKM14el
key:                  tasty-checklist-1.0.6.0-A2pUb4I7ATf5kS2zKM14el
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Check multiple items during a tasty test
description:
    Allows the test to check a number of items during a test and
    only signal pass or fail when the end if the checklist is reached.

    Also provides an easy method to check multiple derived values from
    a single input value.

category:             Testing
abi:                  e695ef20c52f52946e36e5d3a9161c8c
exposed:              True
exposed-modules:      Test.Tasty.Checklist
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-checklist
hs-libraries:         HStasty-checklist-1.0.6.0-A2pUb4I7ATf5kS2zKM14el
depends:
    base-4.17.2.1 containers-0.6.7 exceptions-0.10.5
    parameterized-utils-2.1.10.0-XeKNrZzcqNDkqvF17mzCA text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-checklist/html/tasty-checklist.haddock

haddock-html:         /usr/share/doc/haskell-tasty-checklist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
